Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorCampbell Barton <ideasman42@gmail.com>2020-06-01 07:41:12 +0300
committerCampbell Barton <ideasman42@gmail.com>2020-06-01 08:00:25 +0300
commit946ae26349eedbd6d7bdd859280c10ad80520417 (patch)
tree5c84a333dfd42772e2da94b55ebc97ad91dfa248 /source/blender/editors/space_sequencer/sequencer_select.c
parentc315e564340024e6f0a415b3853421cd35b7a650 (diff)
UI: use term current frame instead of playhead
Avoid mixing different terminologies up, current frame is used in a majority of Blender.
Diffstat (limited to 'source/blender/editors/space_sequencer/sequencer_select.c')
-rw-r--r--source/blender/editors/space_sequencer/sequencer_select.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/source/blender/editors/space_sequencer/sequencer_select.c b/source/blender/editors/space_sequencer/sequencer_select.c
index a8779d96248..25e1b70482e 100644
--- a/source/blender/editors/space_sequencer/sequencer_select.c
+++ b/source/blender/editors/space_sequencer/sequencer_select.c
@@ -412,7 +412,7 @@ static int sequencer_select_exec(bContext *C, wmOperator *op)
ret_value = OPERATOR_FINISHED;
}
/* Select left, right or under playhead. */
else if (left_right != SEQ_SELECT_LR_NONE) {
/* Use different logic for this. */
float x;
@@ -422,7 +422,7 @@ static int sequencer_select_exec(bContext *C, wmOperator *op)
switch (left_right) {
case SEQ_SELECT_LR_MOUSE: {
/* 10px margin around playhead to select under playhead with mouse. */
float margin = BLI_rctf_size_x(&v2d->cur) / BLI_rcti_size_x(&v2d->mask) * 10;
x = UI_view2d_region_to_view_x(v2d, mval[0]);
if (x >= CFRA - margin && x <= CFRA + margin) {
@@ -443,7 +443,7 @@ static int sequencer_select_exec(bContext *C, wmOperator *op)
}
SEQP_BEGIN (ed, seq) {
- /* Select under playhead. */
+ /* Select overlapping the current frame. */
if ((x == CFRA) && (seq->startdisp <= CFRA) && (seq->enddisp >= CFRA)) {
seq->flag = SELECT;
recurs_sel_seq(seq);
@@ -643,9 +643,9 @@ void SEQUENCER_OT_select(wmOperatorType *ot)
static const EnumPropertyItem sequencer_select_left_right_types[] = {
{SEQ_SELECT_LR_NONE, "NONE", 0, "None", "Don't do left-right selection"},
{SEQ_SELECT_LR_MOUSE, "MOUSE", 0, "Mouse", "Use mouse position for selection"},
- {SEQ_SELECT_LR_LEFT, "LEFT", 0, "Left", "Select to the left of the playhead"},
- {SEQ_SELECT_LR_RIGHT, "RIGHT", 0, "Right", "Select to the right of the playhead"},
- {SEQ_SELECT_LR_UNDER_PLAYHEAD, "UNDER", 0, "Under", "Select under the playhead"},
+ {SEQ_SELECT_LR_LEFT, "LEFT", 0, "Left", "Select to the left of the current frame"},
+ {SEQ_SELECT_LR_RIGHT, "RIGHT", 0, "Right", "Select to the right of the current frame"},
+ {SEQ_SELECT_LR_UNDER_PLAYHEAD, "UNDER", 0, "Under", "Select under the current frame"},
{0, NULL, 0, NULL, NULL},
};
PropertyRNA *prop;
@@ -412,7 +412,7 @@ static int sequencer_select_exec(bContext *C, wmOperator *op)
ret_value = OPERATOR_FINISHED;
}
- /* Select left, right or under playhead. */
+ /* Select left, right or overlapping the current frame. */
else if (left_right != SEQ_SELECT_LR_NONE) {
/* Use different logic for this. */
@@ -422,7 +422,7 @@ static int sequencer_select_exec(bContext *C, wmOperator *op)
switch (left_right) {
case SEQ_SELECT_LR_MOUSE: {
- /* 10px margin around playhead to select under playhead with mouse. */
+ /* 10px margin around current frame to select under the current frame with mouse. */
float margin = BLI_rctf_size_x(&v2d->cur) / BLI_rcti_size_x(&v2d->mask) * 10;
x = UI_view2d_region_to_view_x(v2d, mval[0]);